@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2016-10-09'; # DATE
-our $VERSION = '1.025'; # VERSION
+our $DATE = '2016-10-13'; # DATE
+our $VERSION = '1.026'; # VERSION
 
 1;
 # ABSTRACT: A benchmark framework
@@ -18,7 +18,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 1.025 of Bencher (from Perl distribution Bencher), released on 2016-10-09.
+This document describes version 1.026 of Bencher (from Perl distribution Bencher), released on 2016-10-13.
 
 =head1 SYNOPSIS
 
@@ -46,7 +46,7 @@ L</"datasets">.
 
 B<(Benchmark) item>. Participant that has been permuted with dataset into code
 ready to run. Usually a scenario does not contain items directly, but only
-participants and datasets, and let Bencher permute them into items.
+participants and datasets, and lets Bencher permute these into items.
 
 =head1 SCENARIO
 
@@ -433,28 +433,28 @@ be given hash argument with the following keys: C<hook_name> (str, set to
 C<before_gen_items>), C<scenario> (hash, unparsed scenario), C<stash> (hash,
 which you can use to pass data between hooks).
 
+=item * before_parse_participants (code)
+
+If specified, then this code will be called before parsing/normalizing
+participants from scenario. Code will be given hash argument with the following
+keys: C<hook_name>, C<scenario>, C<stash>.
+
+You can use this hook to, e.g.: generate participants dynamically.
+
+=item * before_parse_datasets (code)
+
+If specified, then this code will be called before parsing/normalizing datasets
+from scenario. Code will be given hash argument with the following keys:
+C<hook_name>, C<scenario>, C<stash>.
+
+You can use this hook to, e.g.: generate datasets dynamically.
+
 =item * after_parse_scenario (code)
 
 If specified, then this code will be called after parsing scenario. Code will be
 given hash argument with the following keys: C<hook_name>, C<scenario> (hash,
 parsed scenario), C<stash>.
 
-=item * before_list_datasets (code)
-
-If specified, then this code will be called before enumerating datasets from
-scenario. Code will be given hash argument with the following keys:
-C<hook_name>, C<scenario>, C<stash>.
-
-You can use this hook to, e.g.: generate datasets dynamically.
-
-=item * before_list_participants (code)
-
-If specified, then this code will be called before enumerating participants from
-scenario. Code will be given hash argument with the following keys:
-C<hook_name>, C<scenario>, C<stash>.
-
-You can use this hook to, e.g.: generate participants dynamically.
-
 =item * before_gen_items (code)
 
 If specified, then this code will be called before generating items. Code will
@@ -470,6 +470,27 @@ If specified, then this code will be called before starting the benchmark. Code
 will be given hash argument with the following keys: C<hook_name>, C<scenario>,
 C<stash>.
 
+=item * before_test_item (code)
+
+If specified, then this code will be called before testing each item's code.
+Code will be given hash argument with the following keys: C<hook_name>,
+C<scenario>, C<stash>, C<item> (itself a hash containing the following keys:
+C<_name>, C<seq>, C<permute>).
+
+=item * after_test_item (code)
+
+If specified, then this code will be called after testing each item's code. Code
+will be given hash argument with the following keys: C<hook_name>, C<scenario>,
+C<stash>, C<item> (itself a hash containing the following keys: C<_name>,
+C<seq>, C<permute>, C<_result>).
+
+Item's code result can be accessed in C<_result> in C<item> hash.
+
+The hook is expected to return false (0 or '') or a string which will be
+interpreted as error message. Thus, this hook can be used to force error during
+an item's test. The hook can be used to check that the item's code has executed
+correctly by checking other side effects aside from the return in C<_result>.
+
 =item * after_bench (code)
 
 If specified, then this code will be called after completing benchmark. Code
